"""Collection of constants.

This module contains the following constants:
ALLOWED_SAMPLING_VALUES - all possible values for the sampling argument
STATISTICS_LIST - list of all available statistics and metrics
CLIMATIC_ZONE - dictionary containing all available climatic zones
SEASON_DICT - mapping of season names to months
ALLOWED_CROPS_VALUES - all possible values for the crops argument
RSTAGS - mapping of aggregation type to resampling tag
"""

ALLOWED_SAMPLING_VALUES = [
    "daily",
    "monthly",
    "seasonal",
    "vegseason",
    "summer",
    "xsummer",
    "annual",
    "custom"
]

STATISTICS_LIST = [
    "aot40",
    "avgdma8epax",
    "count",
    "dark_aot40",
    "dark_avg",
    "data_capture",
    "daylight_aot40",
    "daylight_avg",
    "daytime_avg",
    "diurnal_cycle",
    "dma8epa",
    "dma8epa_strict",
    "dma8epax",
    "dma8epax_strict",
    "dma8eu",
    "dma8eu_strict",
    "drmdmax1h",
    "m7_avg",
    "max",
    "max1h",
    "mean",
    "median",
    "min",
    "nighttime_avg",
    "nvgt050",
    "nvgt060",
    "nvgt070",
    "nvgt080",
    "nvgt090",
    "nvgt100",
    "nvgt120",
    "nvgtall",
    "p05",
    "p10",
    "p25",
    "p75",
    "p90",
    "p95",
    "p98",
    "p99",
    "percentiles1",
    "percentiles2",
    "somo10",
    "somo10_strict",
    "somo35",
    "somo35_strict",
    "stddev",
    "w126",
    "w126_24h",
    "w90"
]

CLIMATIC_ZONE = {
    -1: "undefined",
    0: "unclassified",
    1: "warm temperate moist",
    2: "warm temperate dry",
    3: "cool temperate moist",
    4: "cool temperate dry",
    5: "polar moist",
    6: "polar dry",
    7: "boreal moist",
    8: "boreal dry",
    9: "tropical montane",
    10: "tropical wet",
    11: "tropical moist",
    12: "tropical dry"
}

SEASON_DICT = {
    "DJF": [12, 1, 2],
    "MAM": [3, 4, 5],
    "JJA": [6, 7, 8],
    "SON": [9, 10, 11],
    "NH-Summer": [4, 5, 6, 7, 8, 9],
    "SH-Summer": [10, 11, 12, 1, 2, 3],
    "NH-XSummer": [3, 4, 5, 6, 7, 8, 9],
    "SH-XSummer": [9, 10, 11, 12, 1, 2, 3],
    "wheat-boreal_moist-NH": [6, 7, 8],
    "wheat-boreal_dry-NH": [6, 7, 8],
    "wheat-cool_temperate_moist-NH": [4, 5, 6],
    "wheat-cool_temperate_dry-NH": [4, 5, 6],
    "wheat-warm_temperate_moist-NH": [3, 4, 5],
    "wheat-warm_temperate_dry-NH": [3, 4, 5],
    "wheat-tropical_montane-NH": [1, 2, 3],
    "wheat-tropical_wet-NH": [1, 2, 3],
    "wheat-tropical_moist-NH": [1, 2, 3],
    "wheat-tropical_dry-NH": [1, 2, 3],
    "wheat-tropical_moist-SH": [7, 8, 9],
    "wheat-tropical_dry-SH": [8, 9, 10],
    "wheat-warm_temperate_moist-SH": [8, 9, 10],
    "wheat-warm_temperate_dry-SH": [8, 9, 10],
    "wheat-cool_temperate_moist_le30-SH": [2, 3, 4],
    "wheat-cool_temperate_dry_le30-SH": [2, 3, 4],
    "wheat-cool_temperate_moist_gt30-SH": [11, 12, 1],
    "wheat-cool_temperate_dry_gt30-SH": [11, 12, 1],
    "rice-cool_temperate_moist-NH": [5, 6, 7],
    "rice-cool_temperate_dry-NH": [5, 6, 7],
    "rice-warm_temperate_moist-NH": [6, 7, 8],
    "rice-warm_temperate_dry-NH": [6, 7, 8],
    "rice-tropical_moist-NH": [7, 8, 9],
    "rice-tropical_montane-NH": [7, 8, 9],
    "rice-tropical_wet-NH": [7, 8, 9],
    "rice-tropical_dry-NH": [8, 9, 10],
    "rice-tropical_moist-SH": [12, 1, 2],
    "rice-tropical_wet-SH": [12, 1, 2],
    "rice-tropical_dry-SH": [1, 2, 3],
    "rice-warm_temperate_moist-SH": [11, 12, 1],
    "rice-warm_temperate_dry-SH": [1, 2, 3],
    "rice-cool_temperate_moist-SH": [12, 1, 2],
    "rice-cool_temperate_dry-SH": [12, 1, 2],
    "Jan": [1],
    "Feb": [2],
    "Mar": [3],
    "Apr": [4],
    "May": [5],
    "Jun": [6],
    "Jul": [7],
    "Aug": [8],
    "Sep": [9],
    "Oct": [10],
    "Nov": [11],
    "Dec": [12]
}

ALLOWED_CROPS_VALUES = [
    "rice",
    "wheat"
]

RSTAGS = {
    "daily": "D",
    "monthly": "MS",
    "seasonal": "YS",
    "summer": "YS",
    "xsummer": "YS",
    "annual": "YS",
    "custom": "100YS"
}
